‘Quad Squad’ born in Utah | Watch News Videos Online
Description: Watch ‘Quad Squad’ born in Utah Video Online, on GlobalNews.ca

News
December 29 2014 9:11pm
00:35

Loading...

# ‘Quad Squad’ born in Utah

After a six-month roller-coaster ride that has taken them to parenthood — not to mention around the world in the news media — the Tyson and Ashley Gardner of Utah County celebrated the arrival of their highly-anticipated quadruplets on Sunday.

<iframe width='670' height='437' frameborder='0' allowfullscreen src='http://globalnews.ca/video/embed/1747659/'>Your browser does not support frames. <a href="http://globalnews.ca/video/1747659/quad-squad-born-in-utah">Click here to view the frameless video.</a>.</iframe>

### More Videos

- ##### Utah couple’s dream of parenthood comes true in the form of quadruplets

  02:00

- ##### Eggnog chugging contest sends man to hospital

  01:40

- ##### 3D printing used in medicine is saving lives

  03:30

### Video Home

- 01:16

  #### News Hour Final BC

  ##### Trageted Shooting in Delta

- 01:53

  #### News Hour Final BC

  ##### Sinkhole in Port Moody

- 01:45

  #### News Hour Final Calgary

  ##### Terrible road conditions in and around Calgary

- 21:50

  #### News Hour Final Toronto

  ##### News Hour Final: Jan 2

- 02:12

  #### News Final Toronto

  ##### Canadians cheer on Team Canada at the World Juniors

- 01:33

  #### Weather

  ##### Snowmobilers save moose from avalanche

- 01:50

  #### World

  ##### Australian authorities declare major emergency due to bushfires

- 01:07

  #### Top Story

  ##### Curtis Lazar says chemistry with McDavid is improving

- 01:03

  #### Top Story

  ##### Connor McDavid says playing at the ACC was ‘very special’

- 00:39

  #### Top Story

  ##### Max Domi says Team Canada captain Curtis Lazar is a great leader

- 00:49

  #### Top Story

  ##### Sam Reinhart says Team Canada is not getting too confident

- 00:30

  #### News Hour Calgary

  ##### Police investigate shooting at Rundle home

- 17:56

  #### News Hour BC

  ##### News Hour: Jan 2

- 09:42

  #### Evening News Regina

  ##### Evening News: Jan 2

- 04:32

  #### News Hour BC

  ##### Satellite Debris – Jan 2

- 01:00

  #### World

  ##### Daschund gets tummy tuck after dramatic weight loss

- 01:54

  #### Evening News Regina

  ##### New costs in 2015

- 03:42

  #### Weather

  ##### BC Evening Forecast: Jan 2

- 01:06

  #### News Hour BC

  ##### Nurse practitioner tested for Ebola released from Rossland hospital

- 01:52

  #### News Hour BC

  ##### Good Samaritan helps catch suspected street racers

- 02:04

  #### News Hour BC

  ##### Happy Wrestling Day Williams Lake!

- 02:00

  #### News Hour BC

  ##### BC grandmother breaks another marathon record

- 22:59

  #### Global National Mandarin

  ##### Global National Mandarin: Jan 2

- 01:42

  #### News Hour BC

  ##### Evergreen Line construction causes second sinkhole

- 03:23

  #### News Hour BC

  ##### BC winter weather woes

- 02:08

  #### News Hour BC

  ##### 2015 BC property assessments: Winners and losers

- 01:59

  #### News Hour BC

  ##### Burnaby family thank neighbours for coming to the rescue

- 01:59

  #### News Hour BC

  ##### Animal activist sentencing hearing for dog theft

- 01:17

  #### World

  ##### Palestine submits documents to join International Criminal Court

- 21:39

  #### News At 5 Okanagan

  ##### Global Okanagan at 5:00 Jan 2 Top Stories